@@ -82,6 +82,11 @@ my @Fields =
    chk => undef,
  },
 
+ { name => 'mag',
+   re => qr/Filter$/,
+   chk => undef
+ },
+
  { name => 'Distance',
    re  => qr/distance/i,
    chk => RE_num_real(),
@@ -132,6 +137,8 @@ my @Fields =
    chk => undef,
  },
 
+
+
   );
 
 ## no critic (AccessOfPrivateData)
